@@ -1,14 +1,16 @@
 describe.factor.bayes<-function(){
-category <- "censored"
+category <- "continuous"
 description  <- "Bayesian Factor Analysis"
 package <-list(	name 	="MCMCpack",
 		version	="0.6"
 		)
 parameters<-list(mu="mu")
 parameters$mu<-list(equations=c(1,1),
-			tagsAllowed=FALSE,
-			depVar=TRUE,
-			expVar=TRUE,
+                    tagsAllowed=FALSE,
+                    depVar=TRUE,
+                    expVar=FALSE,
+                    specialFunction="cbind",
+                    varInSpecialFunction=c(3,Inf)
 		)
 			
 list(category=category,description=description,package=package,parameters=parameters)
