@@ -8,6 +8,6 @@ print.summary.MCMCZelig <- function(x, digits=max(3, getOption("digits") -
   cat("Sample size per chain =", (x$end -
   x$start)/x$thin + 1, "\n")
   cat("\n", "Mean, standard deviation, and quantiles for marginal posterior distributions.", "\n")
-  print.matrix(round(x$summary, digits=digits))
+  print(round(x$summary, digits=digits))
   cat("\n")
 }
